==> dnet-openaireplus-workflows-7.0.5-20200414.093305-6-sources.jar: eu/dnetlib/msro/openaireplus/workflows/nodes/dhp/DeleteMDStoreHadoopJobNode.java <==
package eu.dnetlib.msro.openaireplus.workflows.nodes.dhp;

import java.net.URI;
import java.util.HashMap;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.annotation.Required;
import org.springframework.web.client.RestTemplate;
import org.springframework.web.util.UriComponentsBuilder;

import com.googlecode.sarasvati.Arc;
import com.googlecode.sarasvati.NodeToken;

import eu.dnetlib.msro.workflows.nodes.SimpleJobNode;

public class DeleteMDStoreHadoopJobNode extends SimpleJobNode {

    private static final Log log = LogFactory.getLog(DeleteMDStoreHadoopJobNode.class);

    private String mdId;

    /* Spring managed params */
    private String mdStoreManagerUrl;

    @Override
    protected String execute(final NodeToken token) throws Exception {
        final String url = getMdStoreManagerUrl() + "/mdstore/{mdId}";

        final Map<String, Object> params = new HashMap<>();
        params.put("mdId", getMdId());

        final URI uri = UriComponentsBuilder.fromUriString(url)
                .buildAndExpand(params)
                .toUri();

        final RestTemplate restTemplate = new RestTemplate();
        restTemplate.delete(uri);

        log.info("mdstor deleted: " + mdId);

        return Arc.DEFAULT_ARC;
    }

    public String getMdStoreManagerUrl() {
        return mdStoreManagerUrl;
    }

    @Required
    public void setMdStoreManagerUrl(final String mdStoreManagerUrl) {
        this.mdStoreManagerUrl = mdStoreManagerUrl;
    }

    public String getMdId() {
        return mdId;
    }

    public void setMdId(final String mdId) {
        this.mdId = mdId;
    }

}

==> dnet-openaireplus-workflows-7.0.9-20210221.032517-2741-sources.jar: eu/dnetlib/msro/openaireplus/workflows/nodes/dhp/DeleteMDStoreHadoopJobNode.java <==
package eu.dnetlib.msro.openaireplus.workflows.nodes.dhp;

import java.net.URI;
import java.util.HashMap;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.annotation.Required;
import org.springframework.web.client.RestTemplate;
import org.springframework.web.util.UriComponentsBuilder;

import com.googlecode.sarasvati.Arc;
import com.googlecode.sarasvati.NodeToken;

import eu.dnetlib.msro.workflows.nodes.SimpleJobNode;

public class DeleteMDStoreHadoopJobNode extends SimpleJobNode {

    private static final Log log = LogFactory.getLog(DeleteMDStoreHadoopJobNode.class);

    private String mdId;

    /* Spring managed params */
    private String mdStoreManagerUrl;

    @Override
    protected String execute(final NodeToken token) throws Exception {
        final String url = getMdStoreManagerUrl() + "/mdstore/{mdId}";

        final Map<String, Object> params = new HashMap<>();
        params.put("mdId", getMdId());

        final URI uri = UriComponentsBuilder.fromUriString(url)
                .buildAndExpand(params)
                .toUri();

        final RestTemplate restTemplate = new RestTemplate();
        restTemplate.delete(uri);

        log.info("mdstore deleted: " + mdId);

        return Arc.DEFAULT_ARC;
    }

    public String getMdStoreManagerUrl() {
        return mdStoreManagerUrl;
    }

    @Required
    public void setMdStoreManagerUrl(final String mdStoreManagerUrl) {
        this.mdStoreManagerUrl = mdStoreManagerUrl;
    }

    public String getMdId() {
        return mdId;
    }

    public void setMdId(final String mdId) {
        this.mdId = mdId;
    }

}
